@@ -13,20 +13,22 @@
 ##'     welcome, even if I cannot guarantee that they will be
 ##'     incorporated to the package.
 ##'
-##' This package makes extensive use of the [igraph] package
+##' This package makes extensive use of the [igraph::igraph] package
 ##'     functions, which should be loaded before using "gor".
 ##'
 ##' Some functions in this package perform tasks which can be found in
-##'     other well-tested packages such as [igraph] or TSP.  As said
-##'     before, these functions have been written with teaching in
-##'     mind, and I do not claim that [gor] functions are better than
-##'     any other in any way whatsoever.
+##'     other well-tested packages such as [igraph::igraph] or
+##'     [TSP::TSP].  As said before, these functions have been written
+##'     with teaching in mind, and I do not claim that "gor" functions
+##'     are better than any other in any way whatsoever.
 ##'
 ##' @import igraph
-##' @author Cesar Asensio (2021-2023)
+##' @author Cesar Asensio (2021-2025)
 ##' @md
 ##' @encoding UTF-8
 ##' @docType package
 ##' @name gor
+##' @keywords internal
+"_PACKAGE"
 NULL
 #> NULL
